@@ -5,7 +5,7 @@ from cpm.api.result import OK
 from cpm.api.result import FAIL
 from cpm.domain.cmake.cmakelists_builder import CMakeListsBuilder
 from cpm.domain.compilation_service import CompilationService
-from cpm.domain.project.project_descriptor_parser import NotACpmProject
+from cpm.domain.project.project_descriptor_parser import ProjectDescriptorNotFound
 from cpm.domain.project.project_loader import ProjectLoader
 from cpm.domain.project_commands import ProjectCommands
 
@@ -13,7 +13,7 @@ from cpm.domain.project_commands import ProjectCommands
 def prep_project(compilation_service, target='default'):
     try:
         compilation_service.update(target)
-    except NotACpmProject:
+    except ProjectDescriptorNotFound:
         return Result(FAIL, f'error: not a cpm project')
 
     return Result(OK, f'CMakeLists.txt ready')
